..
      Copyright European Organization for Nuclear Research (CERN)

      Licensed under the Apache License, Version 2.0 (the "License");
      You may not use this file except in compliance with the License.
      You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0




==========================================
REST API Automatic Generated Documentation
==========================================

**WARNING**

The following documentation was generated automatically from a script in tools/generateRESTDocs.py.

This script extract useful information directly from source code, but with a best effort approach.

In any case, this documentation can be helpful, but in some cases will be **PLAIN WRONG**.

In some cases the URLs reported are incomplete, the raised exceptions will contain strange strings and in all the cases the correct return value (which usually is **200 OK** or **203 CREATED**) in case of no error is omitted.

The documentation is organized by source code, so REST_account.html will contain the documentation for the rucio/web/rest/acccount.py source file.

If you found an inconsistency with the behavior of Rucio REST API and this documentation, please don't hesitate in submit a JIRA_ ticket.

.. _`JIRA`: https://its.cern.ch/jira/browse/RUCIO

Automatic Generated Docs
========================
.. toctree::
    :maxdepth: 1

    REST_Account
    REST_authentication
    REST_did
    REST_identity
    REST_lock
    REST_meta
    REST_redirect
    REST_replica
    REST_rse
    REST_rule
    REST_scope
    REST_subscription

